@@ -33,7 +33,7 @@
 	f = (stomp_frame_t *) emalloc(sizeof(stomp_frame_t)); \
 	f->command = NULL; f->body = NULL; \
 	ALLOC_HASHTABLE(f->headers); \
-	zend_hash_init(f->headers, 0, NULL, ZVAL_PTR_DTOR, 0);
+	zend_hash_init(f->headers, 0, NULL, NULL, 0);
 
 typedef struct _stomp_options {
 	long connect_timeout_sec;
@@ -90,8 +90,7 @@ int stomp_select_ex(stomp_t *connection, const long int sec, const long int usec
 void stomp_set_error(stomp_t *stomp, const char *error, int errnum, const char *fmt, ...) ZEND_ATTRIBUTE_PTR_FORMAT(printf, 4, 0);
 void stomp_free_frame(stomp_frame_t *frame);
 
-#define stomp_select(s) stomp_select_ex(s, s->options.read_timeout_sec, s->options.read_timeout_usec)
-#define stomp_read_frame(c) stomp_read_frame_ex(c, 1)
+#define stomp_select(s) stomp_select_ex(s, s->options.read_timeout_sec, s->options.read_timeout_sec)
 #endif /* _STOMP_H_ */
 
 /*
